@@ -100,12 +100,14 @@ def update(profile_name, stack_file, stack_name, secret, slack_webhook_url,
         exit(1)
 
     # Get auth
-    if profile_name is not None:
-        try:
-            boto3.setup_default_session(profile_name=profile_name)
-        except Exception as exc:
-            print(exc)
-            exit(1)
+    if not from_pipeline:
+        if profile_name is not None:
+            try:
+                boto3.setup_default_session(profile_name=profile_name)
+            except Exception as exc:
+                print(exc)
+                exit(1)
+
     # Verify integrity of stack
     stacks = None
     try:
